/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package ch03_link;

import helper.TestHelper;
import org.junit.*;
import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.chrome.ChromeDriver;

/**
 *
 * @author Administrator
 */
public class HyperLinkTest {

    static WebDriver driver = new ChromeDriver();


    @BeforeClass
    public static void beforeAll() throws Exception {
    }

    @Before
    public void before() throws Exception {
        driver.get(TestHelper.siteUrl()  + "link.html");
    }

    @Test
    public void testClickLinkByText() throws Exception {
        driver.findElement(By.linkText("Recommend Selenium")).click();
    }

    @Test
    public void testClickLinkByID() throws Exception {
        driver.findElement(By.id("recommend_selenium_link")).click();
    }

    @Test
    public void testClickLinkByPartialText() throws Exception {
        driver.findElement(By.partialLinkText("Recommend Seleni")).click();
    }

    @Test
    public void testClickLinkByXPath() throws Exception {
        driver.findElement(By.xpath("//p/a[text()='Recommend Selenium']")).click();
    }

    @Test
    public void testClickLinkByXPathFunctions() throws Exception {
        // Click the link (two on the same page), click the second one by narrowing down with parent div
        // using XPath contains() functions
        driver.findElement(By.xpath("//div[contains(text(), \"Second\")]/a[text()=\"Click here\"]")).click();
    }

    @Test
    public void testClick3rdLinkUnderParagraphByCSS() throws Exception {
        driver.findElement(By.cssSelector("p  > a:nth-child(3)")).click(); // the 3rd link
    }

    @Test
    public void testClickLinkByArrayIndex() throws Exception {
        assert driver.findElements(By.linkText("Same link")).size() == 2;
        driver.findElements(By.linkText("Same link")).get(1).click();
        assert driver.getPageSource().contains("second link page");
    }

    @Test
    public void testClickLinkOpenningNewWindowsOrTab() throws Exception {
        String currentUrl = driver.getCurrentUrl();
        String newWindowUrl = driver.findElement(By.linkText("Open new window")).getAttribute("href");
        driver.navigate().to(newWindowUrl);
        driver.findElement(By.name("name")).sendKeys("sometext");
        driver.navigate().to(currentUrl); // back
    }

    @Test
    public void testRetrieveCommonLinkDetails() throws Exception {
        WebElement seleniumLink = driver.findElement(By.linkText("Recommend Selenium"));
        assert seleniumLink.getAttribute("href").equals(TestHelper.siteUrl() + "index.html");
        assert "recommend_selenium_link".equals(seleniumLink.getAttribute("id"));
        assert "Recommend Selenium".equals(seleniumLink.getText());
        assert "a".equals(seleniumLink.getTagName());
    }

    @Test
    public void testRetrieveAdvancedLinkDetails() throws Exception {
        assert "font-size: 14px;".equals(driver.findElement(By.id("recommend_selenium_link")).getAttribute("style"));
        //  Please note using attribute_value("style") won't work
        assert "123".equals(driver.findElement(By.id("recommend_selenium_link")).getAttribute("data-id"));
    }

    @Test
    public void testVerifyLinkPresent() throws Exception {
        assert driver.findElement(By.linkText("Recommend Selenium")).isDisplayed();
        assert driver.findElement(By.id("recommend_selenium_link")).isDisplayed();
    }

    @Test
    public void testVerifyLinkDsiplayedOrHidden() throws Exception {
        assert driver.findElement(By.linkText("Recommend Selenium")).isDisplayed();
        assert driver.findElement(By.id("recommend_selenium_link")).isDisplayed();
        driver.findElement(By.linkText("Hide")).click();

        Thread.sleep(1000);
        try {
            // different from Watir, selenium returns element not found
            assert !driver.findElement(By.linkText("Recommend Selenium")).isDisplayed();
        } catch (Exception ex) {
            System.out.println("[Selenium] The hidden link cannot be found");
        }

        driver.findElement(By.linkText("Show")).click();
        Thread.sleep(1000);
        assert driver.findElement(By.linkText("Recommend Selenium")).isDisplayed();
    }

    @After
    public void after() throws Exception {
    }

    @AfterClass
    public static void afterAll() throws Exception {
        driver.quit();
    }
}
